summaryrefslogtreecommitdiff
path: root/compiler/rename
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2019-09-11 21:19:39 +0200
committerMarge Bot <ben+marge-bot@smart-cactus.org>2019-09-20 05:14:34 -0400
commit5119296440e6846c553c72b8a93afc5ecfa576f0 (patch)
treeff508560a4996afffb24bf3af5dfa9c56a7e5c77 /compiler/rename
parent4853d962289db1b32886ec73e824cd37c9c5c002 (diff)
downloadhaskell-5119296440e6846c553c72b8a93afc5ecfa576f0.tar.gz
Module hierarchy: Hs (#13009)
Add GHC.Hs module hierarchy replacing hsSyn. Metric Increase: haddock.compiler
Diffstat (limited to 'compiler/rename')
-rw-r--r--compiler/rename/RnBinds.hs4
-rw-r--r--compiler/rename/RnEnv.hs2
-rw-r--r--compiler/rename/RnExpr.hs4
-rw-r--r--compiler/rename/RnExpr.hs-boot2
-rw-r--r--compiler/rename/RnFixity.hs2
-rw-r--r--compiler/rename/RnHsDoc.hs2
-rw-r--r--compiler/rename/RnNames.hs4
-rw-r--r--compiler/rename/RnPat.hs6
-rw-r--r--compiler/rename/RnSource.hs6
-rw-r--r--compiler/rename/RnSplice.hs2
-rw-r--r--compiler/rename/RnSplice.hs-boot2
-rw-r--r--compiler/rename/RnTypes.hs6
-rw-r--r--compiler/rename/RnUtils.hs2
13 files changed, 22 insertions, 22 deletions
diff --git a/compiler/rename/RnEnv.hs b/compiler/rename/RnEnv.hs
index 91cf8f22f4..d9dbbee891 100644
--- a/compiler/rename/RnEnv.hs
+++ b/compiler/rename/RnEnv.hs
@@ -48,7 +48,7 @@ import GhcPrelude
import LoadIface ( loadInterfaceForName, loadSrcInterface_maybe )
import IfaceEnv
-import HsSyn
+import GHC.Hs
import RdrName
import HscTypes
import TcEnv
diff --git a/compiler/rename/RnExpr.hs-boot b/compiler/rename/RnExpr.hs-boot
index b325eeb6f0..8a9c7818a1 100644
--- a/compiler/rename/RnExpr.hs-boot
+++ b/compiler/rename/RnExpr.hs-boot
@@ -1,6 +1,6 @@
module RnExpr where
import Name
-import HsSyn
+import GHC.Hs
import NameSet ( FreeVars )
import TcRnTypes
import SrcLoc ( Located )
diff --git a/compiler/rename/RnFixity.hs b/compiler/rename/RnFixity.hs
index 665d87747b..198a0441e5 100644
--- a/compiler/rename/RnFixity.hs
+++ b/compiler/rename/RnFixity.hs
@@ -14,7 +14,7 @@ module RnFixity ( MiniFixityEnv,
import GhcPrelude
import LoadIface
-import HsSyn
+import GHC.Hs
import RdrName
import HscTypes
import TcRnMonad
diff --git a/compiler/rename/RnHsDoc.hs b/compiler/rename/RnHsDoc.hs
index 348f87fca5..deaedb8bca 100644
--- a/compiler/rename/RnHsDoc.hs
+++ b/compiler/rename/RnHsDoc.hs
@@ -5,7 +5,7 @@ module RnHsDoc ( rnHsDoc, rnLHsDoc, rnMbLHsDoc ) where
import GhcPrelude
import TcRnTypes
-import HsSyn
+import GHC.Hs
import SrcLoc
diff --git a/compiler/rename/RnPat.hs b/compiler/rename/RnPat.hs
index 150b1cd23f..61cdc140bf 100644
--- a/compiler/rename/RnPat.hs
+++ b/compiler/rename/RnPat.hs
@@ -48,7 +48,7 @@ import {-# SOURCE #-} RnSplice ( rnSplicePat )
#include "HsVersions.h"
-import HsSyn
+import GHC.Hs
import TcRnMonad
import TcHsSyn ( hsOverLitName )
import RnEnv
@@ -319,7 +319,7 @@ rnPats ctxt pats thing_inside
; unCpsRn (rnLPatsAndThen (matchNameMaker ctxt) pats) $ \ pats' -> do
{ -- Check for duplicated and shadowed names
-- Must do this *after* renaming the patterns
- -- See Note [Collect binders only after renaming] in HsUtils
+ -- See Note [Collect binders only after renaming] in GHC.Hs.Utils
-- Because we don't bind the vars all at once, we can't
-- check incrementally for duplicates;
-- Nor can we check incrementally for shadowing, else we'll
@@ -642,7 +642,7 @@ rnHsRecFields ctxt mk_arg (HsRecFields { rec_flds = flds, rec_dotdot = dotdot })
-- due to #15884
- rn_dotdot :: Maybe (Located Int) -- See Note [DotDot fields] in HsPat
+ rn_dotdot :: Maybe (Located Int) -- See Note [DotDot fields] in GHC.Hs.Pat
-> Maybe Name -- The constructor (Nothing for an
-- out of scope constructor)
-> [LHsRecField GhcRn arg] -- Explicit fields
diff --git a/compiler/rename/RnSplice.hs b/compiler/rename/RnSplice.hs
index 9c3e317958..3e6d64751d 100644
--- a/compiler/rename/RnSplice.hs
+++ b/compiler/rename/RnSplice.hs
@@ -16,7 +16,7 @@ import GhcPrelude
import Name
import NameSet
-import HsSyn
+import GHC.Hs
import RdrName
import TcRnMonad
diff --git a/compiler/rename/RnSplice.hs-boot b/compiler/rename/RnSplice.hs-boot
index 7844acd2c9..cd6021027e 100644
--- a/compiler/rename/RnSplice.hs-boot
+++ b/compiler/rename/RnSplice.hs-boot
@@ -1,7 +1,7 @@
module RnSplice where
import GhcPrelude
-import HsSyn
+import GHC.Hs
import TcRnMonad
import NameSet
diff --git a/compiler/rename/RnUtils.hs b/compiler/rename/RnUtils.hs
index a4715a23f6..6678ad6dbf 100644
--- a/compiler/rename/RnUtils.hs
+++ b/compiler/rename/RnUtils.hs
@@ -33,7 +33,7 @@ where
import GhcPrelude
-import HsSyn
+import GHC.Hs
import RdrName
import HscTypes
import TcEnv
diff --git a/compiler/rename/RnBinds.hs b/compiler/rename/RnBinds.hs
index 5bb76f8f0d..811a81bdb1 100644
--- a/compiler/rename/RnBinds.hs
+++ b/compiler/rename/RnBinds.hs
@@ -30,7 +30,7 @@ import GhcPrelude
import {-# SOURCE #-} RnExpr( rnLExpr, rnStmts )
-import HsSyn
+import GHC.Hs
import TcRnMonad
import RnTypes
import RnPat
@@ -248,7 +248,7 @@ rnLocalValBindsLHS fix_env binds
-- Check for duplicates and shadowing
-- Must do this *after* renaming the patterns
- -- See Note [Collect binders only after renaming] in HsUtils
+ -- See Note [Collect binders only after renaming] in GHC.Hs.Utils
-- We need to check for dups here because we
-- don't don't bind all of the variables from the ValBinds at once
diff --git a/compiler/rename/RnExpr.hs b/compiler/rename/RnExpr.hs
index eadb4bca03..6485c004a6 100644
--- a/compiler/rename/RnExpr.hs
+++ b/compiler/rename/RnExpr.hs
@@ -26,7 +26,7 @@ import GhcPrelude
import RnBinds ( rnLocalBindsAndThen, rnLocalValBindsLHS, rnLocalValBindsRHS,
rnMatchGroup, rnGRHS, makeMiniFixityEnv)
-import HsSyn
+import GHC.Hs
import TcEnv ( isBrackStage )
import TcRnMonad
import Module ( getModule )
@@ -916,7 +916,7 @@ rnStmt ctxt _ (L loc (TransStmt { trS_stmts = stmts, trS_by = by, trS_form = for
; let all_fvs = fvs1 `plusFV` fvs2 `plusFV` fvs3
`plusFV` fvs4 `plusFV` fvs5
bndr_map = used_bndrs `zip` used_bndrs
- -- See Note [TransStmt binder map] in HsExpr
+ -- See Note [TransStmt binder map] in GHC.Hs.Expr
; traceRn "rnStmt: implicitly rebound these used binders:" (ppr bndr_map)
; return (([(L loc (TransStmt { trS_ext = noExtField
diff --git a/compiler/rename/RnNames.hs b/compiler/rename/RnNames.hs
index 5bfc1a37d8..738f4c6ab5 100644
--- a/compiler/rename/RnNames.hs
+++ b/compiler/rename/RnNames.hs
@@ -32,7 +32,7 @@ module RnNames (
import GhcPrelude
import DynFlags
-import HsSyn
+import GHC.Hs
import TcEnv
import RnEnv
import RnFixity
@@ -607,7 +607,7 @@ extendGlobalRdrEnvRn avails new_fixities
getLocalDeclBindersd@ returns the names for an HsDecl
It's used for source code.
*** See Note [The Naming story] in HsDecls ****
* *
********************************************************************* -}
@@ -607,7 +607,7 @@ extendGlobalRdrEnvRn avails new_fixities
getLocalDeclBindersd@ returns the names for an HsDecl
It's used for source code.
- *** See Note [The Naming story] in HsDecls ****
+ *** See Note [The Naming story] in GHC.Hs.Decls ****
* *
********************************************************************* -}
diff --git a/compiler/rename/RnSource.hs b/compiler/rename/RnSource.hs
index 79280ee43f..229c66fda4 100644
--- a/compiler/rename/RnSource.hs
+++ b/compiler/rename/RnSource.hs
@@ -21,7 +21,7 @@ import GhcPrelude
import {-# SOURCE #-} RnExpr( rnLExpr )
import {-# SOURCE #-} RnSplice ( rnSpliceDecl, rnTopSpliceDecls )
-import HsSyn
+import GHC.Hs
import FieldLabel
import RdrName
import RnTypes
@@ -1617,7 +1617,7 @@ dataDeclHasCUSK tyvars new_or_data no_rhs_kvs has_kind_sig = do
| NewType <- new_or_data =
unlifted_newtypes && not has_kind_sig
| otherwise = False
- -- See Note [CUSKs: complete user-supplied kind signatures] in HsDecls
+ -- See Note [CUSKs: complete user-supplied kind signatures] in GHC.Hs.Decls
; cusks_enabled <- xoptM LangExt.CUSKs
; return $ cusks_enabled && hsTvbAllKinded tyvars &&
no_rhs_kvs && not non_cusk_newtype
@@ -2073,7 +2073,7 @@ rnConDecl decl@(ConDeclGADT { con_names = names
RecCon {} -> (new_args, new_res_ty)
PrefixCon as | (arg_tys, final_res_ty) <- splitHsFunType new_res_ty
-> ASSERT( null as )
- -- See Note [GADT abstract syntax] in HsDecls
+ -- See Note [GADT abstract syntax] in GHC.Hs.Decls
(PrefixCon arg_tys, final_res_ty)
new_qtvs = HsQTvs { hsq_ext = implicit_tkvs
diff --git a/compiler/rename/RnTypes.hs b/compiler/rename/RnTypes.hs
index 80b03d3f25..e982e72f82 100644
--- a/compiler/rename/RnTypes.hs
+++ b/compiler/rename/RnTypes.hs
@@ -38,7 +38,7 @@ import GhcPrelude
import {-# SOURCE #-} RnSplice( rnSpliceType )
import DynFlags
-import HsSyn
+import GHC.Hs
import RnHsDoc ( rnLHsDoc, rnMbLHsDoc )
import RnEnv
import RnUtils ( HsDocContext(..), withHsDocContext, mapFvRn
@@ -280,7 +280,7 @@ partition_nwcs free_vars
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Identifiers starting with an underscore are always parsed as type variables.
It is only here in the renamer that we give the special treatment.
-See Note [The wildcard story for types] in HsTypes.
+See Note [The wildcard story for types] in GHC.Hs.Types.
It's easy! When we collect the implicitly bound type variables, ready
to bring them into scope, and NamedWildCards is on, we partition the
@@ -803,7 +803,7 @@ bindHsQTyVars :: forall a b.
-- The Bool is True <=> all kind variables used in the
-- kind signature are bound on the left. Reason:
-- the last clause of Note [CUSKs: Complete user-supplied
- -- kind signatures] in HsDecls
+ -- kind signatures] in GHC.Hs.Decls
-> RnM (b, FreeVars)
-- See Note [bindHsQTyVars examples]